@@ -1,26 +1,29 @@
+  # Variables
   peran_multi <<- 0
+  ysup_multi <- max(NMRData_plot[1,])
+  yinf_multi <- -100
 
-  ysup_multi <- max(NMRData[1,])
 
-  yinf_multi <- ysup_multi*-0.03
 
   ysup_multi <- ysup_multi + ysup_multi*0.03
+  chkzoom_multi <<- 1
+  idb_multi <<- 0
 
 
-  # data.frame
-  testy_multi <<- data.frame(Chemical_Shift=CS_values_real[1,],Spectrum=NMRData[1,])
+  # Data.frame
+  testy_multi <<- data.frame(Chemical_Shift=CS_values_real[1,],Spectrum=NMRData_plot[1,])
+  ranges_multi <- reactiveValues(x = c((min(testy_multi$Chemical_Shift)), max(testy_multi$Chemical_Shift)), y = c(yinf_multi,ysup_multi)) ## ESSE É O ORIGINAL
+  # ranges_multi_plot <- reactiveValues(x = sort(c((min(testy_multi$Chemical_Shift)), max(testy_multi$Chemical_Shift)), decreasing = TRUE), y = c(yinf_multi,ysup_multi))
+  spectrums_multi <- reactiveValues(dat = data.frame(Chemical_Shift=CS_values_real[1,],Spectrum=NMRData_plot[1,]))
 
-
-  ranges_multi <- reactiveValues(x = c((min(testy_multi$Chemical_Shift)), max(testy_multi$Chemical_Shift)), y = c(yinf_multi,ysup_multi))
-
-  spectrums_multi <- reactiveValues(dat = data.frame(Chemical_Shift=CS_values_real[1,],Spectrum=NMRData[1,]))
-
-  # plot
+  # Plot
     output$plot_multi <- plotly::renderPlotly({
 
-      ggplot2::ggplot(spectrums_multi$dat,ggplot2::aes(Chemical_Shift,Spectrum)) + ggplot2::geom_line(color='blue') +
+      ggplot2::ggplot(spectrums_multi$dat,ggplot2::aes(Chemical_Shift,Spectrum)) + ggplot2::geom_line(color='blue') + ggplot2::scale_x_reverse() +
 
-        ggplot2::coord_cartesian(xlim = ranges_multi$x, ylim = ranges_multi$y, expand = FALSE) + ggplot2::scale_x_reverse() +
+        # ggplot2::coord_cartesian(xlim = ranges_multi$x, ylim = ranges_multi$y, expand = FALSE) +  ## COMANDO ANTIGO QUE ESTÁ OK PARA GGPLOT2 3.2.1
+
+        ggplot2::coord_cartesian(xlim = c(ranges_multi$x[2],ranges_multi$x[1]), ylim = ranges_multi$y, expand = FALSE) + ## COMANDO QUE ESTÁ OK PARA GGPLOT2 3.3
 
         ggplot2::theme(axis.text.x = ggplot2::element_text(size = 12, color = "#000000"),
                        axis.text.y = ggplot2::element_text(size = 12, color = "#000000"),
@@ -30,40 +33,13 @@
 
         ggplot2::labs(x = "Chemical Shift", y = "Intensity")
 
-
-
     })
 
-  # observeEvent(input$plot_brush_multi,{
-  #
-  #   brush <- input$plot_brush_multi
-  #
-  #   if (!is.null(brush)) {
-  #
-  #     ranges_multi$x <- c(brush$xmin, brush$xmax)
-  #
-  #     ranges_multi$y <- c(brush$ymin, brush$ymax)
-  #
-  #     idb_multi <<- 1
-  #
-  #     peran_multi <<- (ranges_multi$x[2] - ranges_multi$x[1])*0.2
-  #
-  #   }
-  #
-  #   else {
-  #
-  #       ranges_multi$x <- NULL
-  #
-  #   }
-  #
-  # })
 
 
-  chkzoom_multi <<- 1
-
-  idb_multi <<- 0
 
 
+  # x2
   observeEvent(input$x2_multi, {
 
     chkzoom_multi <<- chkzoom_multi*2
@@ -73,6 +49,7 @@
     })
 
 
+  # x8
   observeEvent(input$x8_multi, {
 
     chkzoom_multi <<- chkzoom_multi*8
@@ -82,6 +59,7 @@
     })
 
 
+  # /2
   observeEvent(input$q2_multi, {
 
     chkzoom_multi <<- chkzoom_multi/2
@@ -91,6 +69,7 @@
     })
 
 
+  # /8
   observeEvent(input$q8_multi, {
 
     chkzoom_multi <<- chkzoom_multi/8
@@ -100,13 +79,14 @@
     })
 
 
+  # Show all
   observeEvent(input$all_multi, {
 
     ranges_multi$x <- c(min(CS_values_real[1,]),(max(CS_values_real[1,])))
 
     freshnum_multi <- which(file_names[] == input$spectrum_list_multi)
 
-    ysup_multi <- max (NMRData[freshnum_multi,])
+    ysup_multi <- max(NMRData_plot[freshnum_multi,])
 
     yinf_multi <- ysup_multi*-0.03
 
@@ -125,6 +105,7 @@
     })
 
 
+  # Move left
   observeEvent(input$s_left_multi, {
 
     if (!(ranges_multi$x[1] <= min(testy_multi$Chemical_Shift))) {
@@ -138,6 +119,7 @@
   })
 
 
+  # Move right
   observeEvent(input$s_right_multi, {
 
     if (!(ranges_multi$x[2] >= max(testy_multi$Chemical_Shift))) {
@@ -151,6 +133,7 @@
   })
 
 
+  # Move full left
   observeEvent(input$s_left_f_multi, {
 
     if (!(ranges_multi$x[1] <= min(testy_multi$Chemical_Shift))) {
@@ -166,6 +149,7 @@
   })
 
 
+  # Move full right
   observeEvent(input$s_right_f_multi, {
 
     if ((ranges_multi$x[2] <= max(testy_multi$Chemical_Shift))) {
@@ -181,15 +165,16 @@
   })
 
 
+  # View samples plot
   observeEvent(input$spectrum_list_multi,{
 
     freshnum_multi <- which(file_names[] == input$spectrum_list_multi)
 
-    spectrums_multi$dat <<- data.frame(Chemical_Shift=CS_values_real[1,],Spectrum=NMRData[freshnum_multi,])
+    spectrums_multi$dat <<- data.frame(Chemical_Shift=CS_values_real[1,],Spectrum=NMRData_plot[freshnum_multi,])
 
     if (!idb_multi && chkzoom_multi == 1) {
 
-      ysup_multi <- max (NMRData[freshnum_multi,])
+      ysup_multi <- max (NMRData_plot[freshnum_multi,])
 
       yinf_multi <- ysup_multi*-0.03
 
@@ -208,13 +193,14 @@
   })
 
 
+  # Second show all (double click)
   observeEvent(input$plot_dblclick_multi, {
 
     ranges_multi$x <- c(min(CS_values_real[1,]),(max(CS_values_real[1,])))
 
     freshnum_multi <- which(file_names[] == input$spectrum_list_multi)
 
-    ysup_multi <- max (NMRData[freshnum_multi,])
+    ysup_multi <- max (NMRData_plot[freshnum_multi,])
 
     yinf_multi <- ysup_multi*-0.03
 
